@@ -43,6 +43,14 @@ def unfollow(user, obj):
     except Follow.DoesNotExist:
         pass
 
+def toggle(user, obj):
+    """ Toggles a follow status. Useful function if you don't want to perform follow
+    checks but just toggle it on / off. """
+    if Follow.objects.is_following(user, obj):
+        return unfollow(user, obj)
+    return follow(user, obj)    
+
+
 def follow_link(object):
     return reverse('follow', args=[object._meta.app_label, object._meta.object_name.lower(), object.pk])
 
